marvelous_carousel library
Enums
- PagerType
- A widget for creating a vertical/horizontal carousel with stacked cards. Select a PagerType from enum PagerType.simple or PagerType.stack PagerType.simple makes an animation that makes an simple effect PagerType.stack makes an animation that makes an stacked animation